@@ -24,7 +24,6 @@
 #include <memory> //For std::shared_ptr<>
 #include <sigc++config.h>
 #include <sigc++/type_traits.h>
-#include <sigc++/trackable.h>
 #include <sigc++/functors/slot.h>
 #include <sigc++/functors/mem_fun.h>
 
@@ -44,8 +43,7 @@ namespace internal
  * invalid slots from the list.
  */
 struct SIGC_API signal_impl
- : public notifiable,
-   public std::enable_shared_from_this<signal_impl>
+ : public std::enable_shared_from_this<signal_impl>
 {
   using size_type = std::size_t;
   using slot_list = std::list<slot_base>;
@@ -290,7 +288,7 @@ protected:
  *
  * @ingroup signal
  */
-struct SIGC_API signal_base : public trackable
+struct SIGC_API signal_base
 {
   using size_type = std::size_t;
 
