@@ -1,5 +1,5 @@
 /*
- * Copyright 2002, The libsigc++ Development Team
+ * Copyright 2002 - 2016, The libsigc++ Development Team
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -16,8 +16,8 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
-#ifndef _SIGC_TRACKABLE_HPP_
-#define _SIGC_TRACKABLE_HPP_
+#ifndef SIGC_TRACKABLE_HPP
+#define SIGC_TRACKABLE_HPP
 #include <list>
 #include <sigc++config.h>
 
@@ -166,4 +166,4 @@ private:
 
 } /* namespace sigc */
 
-#endif /* _SIGC_TRACKABLE_HPP_ */
+#endif /* SIGC_TRACKABLE_HPP */
