@@ -1,3 +1,7 @@
+/* Copyright 2007 - 2016, The libsigc++ Development Team
+ *  Assigned to public domain.  Use as you wish without restriction.
+ */
+
 #include "testutilities.h"
 #include <sigc++/sigc++.h>
 #include <sstream>
@@ -20,8 +24,9 @@ struct min_accum
 {
   using result_type = T;
 
-  template <class I>
-  typename std::iterator_traits<I>::value_type operator()(I i1, I i2)
+  template <typename I>
+  decltype(auto)
+  operator()(I i1, I i2)
   {
     return *std::min_element(i1, i2);
   }
