@@ -1,5 +1,4 @@
-// -*- c++ -*-
-/* Copyright 2002, The libsigc++ Development Team
+/* Copyright 2002 - 2016, The libsigc++ Development Team
  *  Assigned to public domain.  Use as you wish without restriction.
  */
 
@@ -33,7 +32,7 @@ struct arithmetic_mean_accumulator
   }
 };
 
-template <class Ret>
+template <typename Ret>
 struct vector_accumulator
 {
   using result_type = std::vector<Ret>;
