@@ -1,5 +1,4 @@
-// -*- c++ -*-
-/* Copyright 2002, The libsigc++ Development Team
+/* Copyright 2002 - 2016, The libsigc++ Development Team
  *  Assigned to public domain.  Use as you wish without restriction.
  */
 
@@ -69,7 +68,7 @@ egon(std::string& str)
 
 struct book : public sigc::trackable
 {
-  book(const std::string& name) : name_(name) {}
+  explicit book(const std::string& name) : name_(name) {}
 
   // non-copyable:
   book(const book&) = delete;
@@ -160,10 +159,6 @@ main(int argc, char* argv[])
 
   sl();
   util->check_result(result_stream, "");
-  // This causes a crash when using g++ 3.3.4 or 3.3.5 (but not 3.4.x) when not specifying
-  // the exact template specialization in visit_each_type() - see the comments there.
-  // It looks like the auto-disconnect does not work, so the last sl() call tries
-  // to access the guest_book data again.
 
   return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
 }
