@@ -1,3 +1,7 @@
+/* Copyright 2005 - 2016, The libsigc++ Development Team
+ *  Assigned to public domain.  Use as you wish without restriction.
+ */
+
 #include "testutilities.h"
 #include <sigc++/sigc++.h>
 #include <sstream>
@@ -12,7 +16,7 @@ std::ostringstream result_stream;
 class Param : public sigc::trackable
 {
 public:
-  Param(const std::string& name) : name_(name) {}
+  explicit Param(const std::string& name) : name_(name) {}
 
   // non-copyable,
   // so it can only be used with sigc::bind() via sigc::ref()
@@ -66,10 +70,6 @@ main(int argc, char* argv[])
   result_stream << "Calling slot when param does not exist:";
   slot_bound();
   util->check_result(result_stream, "Calling slot when param does not exist:");
-  // This causes a crash when using g++ 3.3.4 or 3.3.5 (but not 3.4.x) when not specifying
-  // the exact template specialization in visit_each_type() - see the comments there.
-  // It looks like the auto-disconnect does not work, so the last slot_bound() call tries
-  // to access the param data again.
 
   return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
 }
