@@ -1,4 +1,4 @@
-/* Copyright 2002, The libsigc++ Development Team
+/* Copyright 2002 - 2016, The libsigc++ Development Team
  *  Assigned to public domain.  Use as you wish without restriction.
  */
 
@@ -81,8 +81,8 @@ main(int argc, char* argv[])
     return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
 
   sigc::signal<int(int)> sig;
-  sigc::signal<int(int)>::iterator confoo;
-  sigc::signal<int(int)>::iterator conbar;
+  sigc::connection confoo;
+  sigc::connection conbar;
   sigc::connection cona; // connection objects are safe to use beyond the life time of a signal.
 
   {
@@ -101,18 +101,18 @@ main(int argc, char* argv[])
   util->check_result(result_stream, "sig is connected to foo, bar (size=2): foo(2) bar(2) ");
 
   A a; // iterators stay valid after further connections.
-  cona = sig.slots().insert(conbar, sigc::mem_fun(a, &A::foo));
+  cona = sig.connect(sigc::mem_fun(a, &A::foo));
   result_stream << "sig is connected to foo, A::foo, bar (size=" << sig.size() << "): ";
   sig(3);
   util->check_result(
-    result_stream, "sig is connected to foo, A::foo, bar (size=3): foo(3) A::foo(3) bar(3) ");
+    result_stream, "sig is connected to foo, A::foo, bar (size=3): foo(3) bar(3) A::foo(3) ");
 
-  conbar->disconnect(); // manual disconnection
+  conbar.disconnect(); // manual disconnection
   result_stream << "sig is connected to foo, A::foo (size=" << sig.size() << "): ";
   sig(4);
   util->check_result(result_stream, "sig is connected to foo, A::foo (size=2): foo(4) A::foo(4) ");
 
-  confoo->disconnect(); // manual disconnection
+  confoo.disconnect(); // manual disconnection
   result_stream << "sig is connected to A::foo (size=" << sig.size() << "): ";
   sig(5);
   util->check_result(result_stream, "sig is connected to A::foo (size=1): A::foo(5) ");
@@ -165,7 +165,7 @@ main(int argc, char* argv[])
   util->check_result(result_stream, "sig is empty (size=0): ");
 
   result_stream << "deleting a signal during emission... ";
-  auto b = new B;
+  auto b = new B; //This is deleted by B::destroy().
   b->emit();
   util->check_result(result_stream, "deleting a signal during emission... Good bye world!");
 
