@@ -1,4 +1,4 @@
-/* Copyright (C) 2013 The libsigc++ Development Team
+/* Copyright (C) 2013 - 2016, The libsigc++ Development Team
  *
  * This file is part of libsigc++.
  *
@@ -62,7 +62,7 @@ class Functor1
 public:
   using result_type = std::string;
 
-  Functor1(const bar_group4& bar) : bar_(bar) {}
+  explicit Functor1(const bar_group4& bar) : bar_(bar) {}
 
   std::string operator()(int i) { return (i < 0) ? "negative" : ((i > 0) ? "positive" : "zero"); }
 
